==> nosql-database_24.4.zip: nosql-database_24.4_20241213/content/license/toc.js <==
define(
{
    "reducedVersion":true,
    "toc":[
        {
            "heading":"Table of Contents",
            "topics":[
                {
                    "title":"Title and Copyright Information",
                    "href":"index.html"
                },
                {
                    "title":"Documentation Accessibility",
                    "href":"shared-global-topic-documentation-accessibility.html"
                },
                {
                    "title":"THIRD PARTY LICENSES",
                    "href":"third-party-licenses.html"
                },
                {
                    "title":"The Apache Software License, Version 2.0",
                    "href":"apache-license.html"
                },
                {
                    "title":"ANTLR 4",
                    "href":"antlr.html"
                },
                {
                    "title":"commons-logging",
                    "href":"commons-logging.html"
                },
                {
                    "title":"GSON",
                    "href":"gson.html"
                },
                {
                    "title":"jackson-core",
                    "href":"jackson-core.html"
                },
                {
                    "title":"JLine 3",
                    "href":"jline.html"
                },
                {
                    "title":"netty",
                    "href":"netty.html"
                },
                {
                    "title":"Reactive Streams",
                    "href":"reactive-streams.html"
                },
                {
                    "title":"slf4j-api",
                    "href":"slf4j-api.html"
                },
                {
                    "title":"sshd-common",
                    "href":"sshd-common.html"
                },
                {
                    "title":"sshd-core",
                    "href":"sshd-core.html"
                },
                {
                    "title":"sshd-sftp",
                    "href":"sshd-sftp.html"
                }
            ]
        }
    ]
});

==> nosql-database_25.3.zip: nosql-database_25.3_20251015/content/license/toc.js <==
define(
{
    "reducedVersion":true,
    "toc":[
        {
            "heading":"Table of Contents",
            "topics":[
                {
                    "title":"Title and Copyright Information",
                    "href":"index.html"
                },
                {
                    "title":"Documentation Accessibility",
                    "href":"do-not-use-shared-global-topic-documentation-accessibility.html"
                },
                {
                    "title":"THIRD PARTY LICENSES",
                    "href":"third-party-licenses.html"
                },
                {
                    "title":"The Apache Software License, Version 2.0",
                    "href":"apache-license.html"
                },
                {
                    "title":"ANTLR 4",
                    "href":"antlr.html"
                },
                {
                    "title":"commons-logging",
                    "href":"commons-logging.html"
                },
                {
                    "title":"GSON",
                    "href":"gson.html"
                },
                {
                    "title":"jackson-core",
                    "href":"jackson-core.html"
                },
                {
                    "title":"JLine",
                    "href":"jline.html"
                },
                {
                    "title":"netty",
                    "href":"netty.html"
                },
                {
                    "title":"Reactive Streams",
                    "href":"reactive-streams.html"
                },
                {
                    "title":"slf4j-api",
                    "href":"slf4j-api.html"
                },
                {
                    "title":"sshd-common",
                    "href":"sshd-common.html"
                },
                {
                    "title":"sshd-core",
                    "href":"sshd-core.html"
                },
                {
                    "title":"sshd-sftp",
                    "href":"sshd-sftp.html"
                },
                {
                    "title":"jctools-core",
                    "href":"jctools-core.html"
                }
            ]
        }
    ]
});
